#!/bin/bash

source /opt/velostrata/velostrata-functions

kernel_ver=`uname -r`

# check and warn about BTRFS mount issues (see HA-3199 or https://github.com/systemd/systemd/issues/927)
btrfs_mnt=`cat /etc/fstab | grep btrfs | grep subvol | wc -l`
if [[ ${btrfs_mnt} -gt 0 && "${kernel_ver}" < "4.2" ]]; then
	velos_log "WARNING: Found BTRFS mounts in /etc/fstab which are known to have issues in this kernel version (${kernel_ver})"
	velos_log "For more details and workaround, please refer to: https://github.com/systemd/systemd/issues/927"
fi

# check for NUMA setting (see HA-3182 or https://docs.microsoft.com/en-us/azure/virtual-machines/virtual-machines-linux-create-upload-centos#centos-6x)
if [[ "${kernel_ver}" < "2.6.37" ]]; then
	numa_disabled=0
	for ff in ${DEFAULT_GRUB_CONFIG_FILES[*]}; do
		if is_real_file ${ff} && [[ `cat ${ff} | grep numa=off | wc -l` -gt 0 ]]; then
			numa_disabled=1
			break
		fi
	done
	if [[ ${numa_disabled} -eq 0 ]]; then
		velos_log "WARNING: Microsoft Azure has limited support for NUMA in this kernel version (${kernel_ver})"
		velos_log "For more details and workaround, please refer to: https://docs.microsoft.com/en-us/azure/virtual-machines/virtual-machines-linux-create-upload-centos#centos-6x"
	fi
fi

# check for GRUB graphics
for ff in ${DEFAULT_GRUB_CONFIG_FILES[*]}; do
	if is_real_file ${ff} && find_active_str $ff "splashimage=" "gfxmenu" "vga="; then
		backup_file=${ff}.velos_bckp
		velos_log "GFX menu or splash image found in ${ff}, saving backup copy to ${backup_file}"
		cp -f ${ff} ${backup_file}
		replace_entry ${ff} "splashimage=" "#splashimage="
		replace_entry ${ff} "gfxmenu" "#gfxmenu"
		replace_entry ${ff} "vga=" "vga-disabled="
	fi
done

exit 0
